Tyyppi.T (tyyppi v0.12.0) View Source
Raw type wrapper. All the macros exported by that module are available in Tyyppi.
Require and use Tyyppi instead.
Link to this section Summary
Functions
Returns true if the type definition was loaded, false otherwise.
Link to this section Types
Specs
ast() :: Macro.t() | {module(), atom(), list() | nil | non_neg_integer()}
Specs
raw() ::
{kind() | ast_lead(), non_neg_integer() | keyword(), simple() | [ast()],
[raw()]}
Specs
t(wrapped) :: %Tyyppi.T{
definition: raw() | nil,
module: module(),
name: atom(),
params: [atom()],
quoted: wrapped,
source: binary() | nil,
type: visibility()
}
The type information in a human-readable format.
For remote types, it’s gathered from
Code.Typespec,
for built-in like atom() it’s simply constructed on the fly.
Link to this section Functions
Specs
Returns true if the type definition was loaded, false otherwise.